%%% Script for initial parameters needed to solve the transmission
%%% expansion planning (TEP) problem by using AC or DC power flow calculation
%%% and also for running TEP (master script0


% Any publication resulting from the use of this m-file shall acknowledge
% it by citing the following paper:

%S. P. Torres and C. A. Castro, Expansion planning for smart transmission
%grids using ac model and shunt compensation, IET Generation,
%Transmission & Distribution, vol. 8, no. 5, pp. 966-975, 2014.
clear
for i=1:1
    
    % i this parameter helps to define the population size

    
    %% Test Systems
          sistema='garver';

         %sistema='garver_WOrdptch';

        % sistema='case24IEEE_AC';

        %sistema='case118IEEE_AC20Renew'

     
   %% DE_PBILc parameters
    
    Particle_Number=i*60; %Number of individuals 
    Max_Gen=120;  %Maximum number of iterations or generations (stop criterion)
    Max_FES=5000; %Maximum number of objective function evaluations (alternative criterion)
    Xmax=5; % Maximum number of transmission lines that can be added in each right-of-way 
    
    nexp=31;  % Number of optimization repetitions
    GM=110; %Theoretical optimum value (used in case it is known)
    
    
    mpc=loadcase(sistema);  % Load system data (defined in separate m-file)
    LineasIniciales=mpc.costo_lineas(:,1); 
    Costos=mpc.costo_lineas(:,2); % Store line cost data
    dim=numel(LineasIniciales);  %Problem dimension (defined by number of right-of-way considered for expansion) 

    
    Xmax = repmat(Xmax, dim, Particle_Number); 
    
    Xmin = LineasIniciales'; 
    Xmin=repmat(Xmin, Particle_Number,1)'; % Initial topology

fhd=@evaluacion_particulas;

    
    tic % Start measuring cpu time
    
    % Call optimization function(defined by user/algorithm developer)
%[xopt,fxopt,fevalcount, FOPT, RunStats]=PSO(Max_Gen,Max_FES,Particle_Number,dim,Xmin,Xmax, GM, nexp, fhd, sistema);  %%% Write here the name file of your algorithm (instead of 'PSO')
[xopt,fxopt,fevalcount, FOPT, RunStats]=DE_PBIL_MT(Max_Gen,Max_FES,Particle_Number,dim,Xmin,Xmax, GM, nexp, fhd, sistema);
    t(i)=toc; % Stop measuring cpu time
    
    
    Particle_name=num2str(Particle_Number);  % Transform particle number to string
    filename=strcat(sistema, '_', Particle_name,date,'F');  % Create a mat file
    % For each optimization run:
    save(filename, 'xopt', 'fxopt', 'fevalcount', 'FOPT', 'RunStats','t') % Store results of selected vairables in .mat archive 
   
end